@@ -5,8 +5,8 @@ from multiprocessing import Process
 import time
 
 
-def start_serve(port, passwd, back_end_url):
-    hub = TaskHub(back_end_url)
+def start_hub_serve(port, passwd, sync):
+    hub = TaskHub(sync)
     HubManager.register('get_hub', callable=lambda: hub)
     hubmanager = HubManager(address=("localhost", port),
                             authkey=passwd.encode("utf-8"))
@@ -14,8 +14,17 @@ def start_serve(port, passwd, back_end_url):
     serve.serve_forever()
 
 
-def serve(port:int,passwd:str,back_end_url:str):
-    p = Process(target=start_serve,args=(port,passwd,back_end_url,))
+def serve(port: int, passwd: str, sync):
+    """[启动taskhub服务]
+
+    Args:
+        port (int): [端口]
+        passwd (str): [设置密码，连接到本taskhub需要提供]
+        sync ([type]): [同步函数，接受一个“done”状态的Task，
+        该函数负责处理这些完成状态的数据，并返回一个bool值，
+        以表示处理成功与否，若成功taskhub将移除改该Task]
+    """
+    p = Process(target=start_hub_serve,args=(port,passwd,sync,))
     p.start()
     time.sleep(3)
     hub = connect("localhost", port, passwd)
